A kernel-owned or fixed mapping is one which sets VMA_PFNMAP_BIT,
VMA_MIXEDMAP_BIT or VMA_DONTEXPAND_BIT, which is precisely what
VMA_SPECIAL_FLAGS tests for other than VMA_IO_BIT, which is safe to drop as
only kernel-owned mappings may set it.

Using these predicates rather than VMA_SPECIAL_FLAGS makes the check
self-documenting and helps eliminate the confusion around 'special' flags.

No functional change intended.

Signed-off-by: Lorenzo Stoakes (ARM) <[email protected]>
---
 mm/vmscan.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/mm/vmscan.c b/mm/vmscan.c
index 09ff20c3df5b..001f8b760266 100644
--- a/mm/vmscan.c
+++ b/mm/vmscan.c
@@ -4418,8 +4418,8 @@ bool lru_gen_look_around(struct page_vma_mapped_walk 
*pvmw, unsigned int nr)
        if (spin_is_contended(pvmw->ptl))
                return true;
 
-       /* exclude special VMAs containing anon pages from COW */
-       if (vma->vm_flags & VM_SPECIAL)
+       /* exclude kernel-owned and fixed VMAs containing anon pages from COW */
+       if (vma_is_kernel_owned(vma) || vma_is_fixed_mapping(vma))
                return true;
 
        /* avoid taking the LRU lock under the PTL when possible */

-- 
2.55.0


Reply via email to